def square(length = 1, width = 1):
    """" This function calculate the geometry of a square"""
    return (legth * width)

def rectangle(length = 1, width = 1):
    """" This function calculate the geometry of a square"""
    return (legth * width)

def circle(radius):
    """" This function calculate the geometry of a square"""
    return (3.14 * radius*radius)
